<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::table('perbandingan_alternatifs', function (Blueprint $table) {
            $table->unsignedBigInteger('waktu_makan_id')->after('kriteria_id')->nullable();
            $table->unsignedBigInteger('komponen_id')->after('waktu_makan_id')->nullable();
            
            $table->foreign('waktu_makan_id')->references('id')->on('waktu_makans')->onDelete('set null');
            $table->foreign('komponen_id')->references('id')->on('komponens')->onDelete('set null');
        });

        Schema::table('skor_makanans', function (Blueprint $table) {
            $table->unsignedBigInteger('waktu_makan_id')->after('kriteria_id')->nullable();
            $table->unsignedBigInteger('komponen_id')->after('waktu_makan_id')->nullable();
            
            $table->foreign('waktu_makan_id')->references('id')->on('waktu_makans')->onDelete('set null');
            $table->foreign('komponen_id')->references('id')->on('komponens')->onDelete('set null');
        });

        if (!Schema::hasTable('consistency_ratios')) {
            Schema::create('consistency_ratios', function (Blueprint $table) {
                $table->id();
                $table->unsignedBigInteger('kriteria_id');
                $table->unsignedBigInteger('komponen_id');
                $table->unsignedBigInteger('waktu_makan_id');
                $table->float('nilai');
                $table->date('tanggal');
                $table->string('status');
                $table->timestamps();

                $table->foreign('kriteria_id')->references('id')->on('kriterias')->onDelete('cascade');
                $table->foreign('komponen_id')->references('id')->on('komponens')->onDelete('cascade');
                $table->foreign('waktu_makan_id')->references('id')->on('waktu_makans')->onDelete('cascade');
            });
        }
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::table('perbandingan_alternatifs', function (Blueprint $table) {
            $table->dropForeign(['waktu_makan_id']);
            $table->dropForeign(['komponen_id']);
            $table->dropColumn(['waktu_makan_id', 'komponen_id']);
        });

        Schema::table('skor_makanans', function (Blueprint $table) {
            $table->dropForeign(['waktu_makan_id']);
            $table->dropForeign(['komponen_id']);
            $table->dropColumn(['waktu_makan_id', 'komponen_id']);
        });

        Schema::dropIfExists('consistency_ratios');
    }
}; 