// Service Worker untuk HeartChoice Notifications
const CACHE_NAME = 'heartchoice-v1';
const urlsToCache = [
    '/',
    '/audio/notification.mp3',
    '/audio/default.mp3',
    '/logo/baru/dutdut.png'
];

// Install event
self.addEventListener('install', event => {
    console.log('Service Worker installing...');
    event.waitUntil(
        caches.open(CACHE_NAME)
            .then(cache => {
                console.log('Opened cache');
                return cache.addAll(urlsToCache);
            })
            .catch(error => {
                console.log('Cache installation failed:', error);
            })
    );
});

// Fetch event
self.addEventListener('fetch', event => {
    event.respondWith(
        caches.match(event.request)
            .then(response => {
                // Return cached version or fetch from network
                return response || fetch(event.request);
            })
            .catch(error => {
                console.log('Fetch failed:', error);
                return fetch(event.request);
            })
    );
});

// Push event untuk notifikasi background
self.addEventListener('push', event => {
    console.log('Push event received:', event);
    
    let notificationData = {
        title: 'HeartChoice',
        body: 'Anda memiliki notifikasi baru!',
        icon: '/logo/baru/dutdut.png',
        badge: '/logo/baru/dutdut.png',
        tag: 'heartchoice-notification',
        requireInteraction: false,
        silent: false,
        vibrate: [200, 100, 200],
        data: {
            url: '/user/notifications'
        }
    };
    
    // Jika ada data dari push message
    if (event.data) {
        try {
            const data = event.data.json();
            notificationData = {
                ...notificationData,
                ...data
            };
        } catch (e) {
            console.log('Error parsing push data:', e);
        }
    }
    
    event.waitUntil(
        self.registration.showNotification(notificationData.title, notificationData)
    );
});

// Notification click event
self.addEventListener('notificationclick', event => {
    console.log('Notification clicked:', event);
    
    event.notification.close();
    
    // Focus ke window yang ada atau buat window baru
    event.waitUntil(
        clients.matchAll({ type: 'window' })
            .then(clientList => {
                // Cari window yang sudah terbuka
                for (let client of clientList) {
                    if (client.url.includes('/user/notifications') && 'focus' in client) {
                        return client.focus();
                    }
                }
                
                // Jika tidak ada window yang terbuka, buka window baru
                if (clients.openWindow) {
                    return clients.openWindow('/user/notifications');
                }
            })
    );
});

// Notification close event
self.addEventListener('notificationclose', event => {
    console.log('Notification closed:', event);
});

// Background sync (untuk fitur offline)
self.addEventListener('sync', event => {
    console.log('Background sync:', event);
    
    if (event.tag === 'background-sync') {
        event.waitUntil(
            // Lakukan sinkronisasi data
            console.log('Performing background sync...')
        );
    }
});

// Message event untuk komunikasi dengan main thread
self.addEventListener('message', event => {
    console.log('Service Worker received message:', event.data);
    
    if (event.data && event.data.type === 'SKIP_WAITING') {
        self.skipWaiting();
    }
    
    // Handle show notification message
    if (event.data && event.data.type === 'SHOW_NOTIFICATION') {
        const notificationData = event.data.notification;
        
        event.waitUntil(
            self.registration.showNotification(notificationData.title, notificationData)
                .then(() => {
                    console.log('Background notification shown successfully');
                })
                .catch(error => {
                    console.error('Error showing background notification:', error);
                })
        );
    }
});

console.log('Service Worker loaded successfully'); 