@extends('layout.app')

@section('title', 'Profile')

@include('admin.shared.admin-styles')

@section('content')
<div class="admin-container container-fluid">
    <!-- Page Header -->
    <div class="page-header animate-fade-in">
        <div class="row align-items-center">
            <div class="col-12">
                <h3 class="mb-2 text-white">
                    <i class="fas fa-user me-2"></i>Profile
                </h3>
                <nav aria-label="breadcrumb">
                    <ol class="breadcrumb mb-0">
                        <li class="breadcrumb-item"><a href="{{ route('admindash') }}" class="text-white-50">Dashboard</a></li>
                        <li class="breadcrumb-item active text-white" aria-current="page">Profile</li>
                    </ol>
                </nav>
            </div>
        </div>
    </div>

    <div class="row">
        <!-- Profile Card -->
        <div class="col-lg-4">
            <div class="admin-card animate-fade-in">
                <div class="card-body text-center">
                    <div class="mb-4">
                        <div class="rounded-circle bg-primary bg-opacity-10 mx-auto p-4 d-flex align-items-center justify-content-center" style="width: 120px; height: 120px;">
                            <i class="bi bi-person-fill text-primary" style="font-size: 3rem;"></i>
                        </div>
                    </div>
                    <h4 class="fw-bold mb-2">{{ $user->name }}</h4>
                    <p class="text-muted mb-3">{{ $user->email }}</p>
                    <div class="admin-badge bg-primary">
                        <i class="bi bi-award me-1"></i>
                        {{ ucfirst($user->role->name ?? 'user') }}
                    </div>
                </div>
            </div>
        </div>

        <!-- Profile Details -->
        <div class="col-lg-8">
            <div class="admin-card animate-fade-in">
                <div class="card-body">
                    <ul class="nav nav-tabs" role="tablist">
                        <li class="nav-item">
                            <a class="nav-link active" data-bs-toggle="tab" href="#tab-profile">
                                <i class="fas fa-user-edit me-2"></i>Edit Profile
                            </a>
                        </li>
                        <li class="nav-item">
                            <a class="nav-link" data-bs-toggle="tab" href="#tab-password">
                                <i class="fas fa-key me-2"></i>Change Password
                            </a>
                        </li>
                    </ul>

                    <div class="tab-content pt-4">
                        <!-- Profile Edit Form -->
                        <div class="tab-pane fade show active" id="tab-profile">
                            @if(session('success'))
                                <div class="admin-alert alert-success" role="alert">
                                    <i class="fas fa-check-circle me-2"></i>{{ session('success') }}
                                </div>
                            @endif

                            @if(session('error'))
                                <div class="admin-alert alert-danger" role="alert">
                                    <i class="fas fa-exclamation-circle me-2"></i>{{ session('error') }}
                                </div>
                            @endif

                            <form action="{{ route('profile.update') }}" method="POST">
                                @csrf
                                @method('PUT')

                                <div class="admin-form-group row">
                                    <label class="col-md-4 col-lg-3 admin-form-label">Full Name</label>
                                    <div class="col-md-8 col-lg-9">
                                        <input name="name" type="text" class="admin-form-control" value="{{ $user->name }}" required>
                                    </div>
                                </div>

                                <div class="admin-form-group row">
                                    <label class="col-md-4 col-lg-3 admin-form-label">Email</label>
                                    <div class="col-md-8 col-lg-9">
                                        <input name="email" type="email" class="admin-form-control" value="{{ $user->email }}" required>
                                    </div>
                                </div>

                                <div class="admin-form-group row">
                                    <label class="col-md-4 col-lg-3 admin-form-label">Phone</label>
                                    <div class="col-md-8 col-lg-9">
                                        <input name="no_telp" type="text" class="admin-form-control" value="{{ $user->no_telp }}">
                                    </div>
                                </div>

                                <div class="admin-form-group row">
                                    <label class="col-md-4 col-lg-3 admin-form-label">Role</label>
                                    <div class="col-md-8 col-lg-9">
                                        <select name="role_id" class="admin-form-control" required>
                                            @foreach (\App\Models\Role::all() as $role)
                                                <option value="{{ $role->id }}" {{ $user->role_id == $role->id ? 'selected' : '' }}>
                                                    {{ $role->name }}
                                                </option>
                                            @endforeach
                                        </select>
                                    </div>
                                </div>

                                <div class="text-center">
                                    <button type="submit" class="admin-btn btn-primary">
                                        <i class="fas fa-save me-2"></i>Save Changes
                                    </button>
                                </div>
                            </form>
                        </div>

                        <!-- Change Password Form -->
                        <div class="tab-pane fade" id="tab-password">
                            <form action="{{ route('profile.password') }}" method="POST">
                                @csrf
                                @method('PUT')

                                <div class="admin-form-group row">
                                    <label class="col-md-4 col-lg-3 admin-form-label">Current Password</label>
                                    <div class="col-md-8 col-lg-9">
                                        <input name="current_password" type="password" class="admin-form-control" required>
                                    </div>
                                </div>

                                <div class="admin-form-group row">
                                    <label class="col-md-4 col-lg-3 admin-form-label">New Password</label>
                                    <div class="col-md-8 col-lg-9">
                                        <input name="password" type="password" class="admin-form-control" required>
                                    </div>
                                </div>

                                <div class="admin-form-group row">
                                    <label class="col-md-4 col-lg-3 admin-form-label">Confirm Password</label>
                                    <div class="col-md-8 col-lg-9">
                                        <input name="password_confirmation" type="password" class="admin-form-control" required>
                                    </div>
                                </div>

                                <div class="text-center">
                                    <button type="submit" class="admin-btn btn-primary">
                                        <i class="fas fa-key me-2"></i>Change Password
                                    </button>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
@endsection
