@extends('layout.app')

@section('title', 'Edit Relasi')

@include('admin.shared.admin-styles')

@section('content')
<div class="admin-container container-fluid">
    <!-- Page Header -->
    <div class="page-header animate-fade-in">
        <div class="row align-items-center">
            <div class="col-12">
                <h3 class="mb-2 text-white">
                    <i class="fas fa-edit me-2"></i>Edit Relasi
                </h3>
            <nav aria-label="breadcrumb">
                    <ol class="breadcrumb mb-0">
                        <li class="breadcrumb-item"><a href="{{ route('admindash') }}" class="text-white-50">Dashboard</a></li>
                        <li class="breadcrumb-item"><a href="{{ route('relasi.index') }}" class="text-white-50">Relasi</a></li>
                        <li class="breadcrumb-item active text-white" aria-current="page">Edit</li>
                </ol>
            </nav>
            </div>
        </div>
    </div>

    <div class="row">
        <div class="col-12">
            <div class="admin-card animate-fade-in">
                <div class="card-body">
                    <h5 class="card-title mb-4">
                        <i class="fas fa-edit me-2"></i>Edit Relasi
            </h5>

            @if(session('success'))
                <div class="alert alert-success" role="alert">
                    <i class="fas fa-check-circle me-2"></i>{{ session('success') }}
                </div>
            @endif

            @if(session('error'))
                <div class="alert alert-danger" role="alert">
                    <i class="fas fa-exclamation-circle me-2"></i>{{ session('error') }}
                </div>
            @endif

            <form action="{{ route('relasi.update', $relasi->id) }}" method="POST">
                @csrf
                @method('PUT')

                        <div class="row g-4">
                    <div class="col-md-4">
                                <div class="admin-form-group">
                                    <label class="admin-form-label">
                                        <i class="fas fa-utensils me-2"></i>Makanan
                                    </label>
                                    <select name="makanan_id" class="admin-form-control @error('makanan_id') is-invalid @enderror">
                                        <option value="">Pilih Makanan</option>
                                @foreach($makanans as $makanan)
                                            <option value="{{ $makanan->id }}" {{ old('makanan_id', $relasi->makanan_id) == $makanan->id ? 'selected' : '' }}>
                                        {{ $makanan->nama }}
                                    </option>
                                @endforeach
                            </select>
                            @error('makanan_id')
                                <div class="invalid-feedback">{{ $message }}</div>
                            @enderror
                        </div>
                    </div>

                    <div class="col-md-4">
                                <div class="admin-form-group">
                                    <label class="admin-form-label">
                                        <i class="fas fa-cube me-2"></i>Komponen
                                    </label>
                                    <select name="komponen_id" class="admin-form-control @error('komponen_id') is-invalid @enderror">
                                        <option value="">Pilih Komponen</option>
                                @foreach($komponens as $komponen)
                                            <option value="{{ $komponen->id }}" {{ old('komponen_id', $relasi->komponen_id) == $komponen->id ? 'selected' : '' }}>
                                        {{ $komponen->nama }}
                                    </option>
                                @endforeach
                            </select>
                            @error('komponen_id')
                                <div class="invalid-feedback">{{ $message }}</div>
                            @enderror
                        </div>
                    </div>

                    <div class="col-md-4">
                                <div class="admin-form-group">
                                    <label class="admin-form-label">
                                        <i class="fas fa-clock me-2"></i>Waktu Makan
                                    </label>
                                    <select name="waktu_makan_id" class="admin-form-control @error('waktu_makan_id') is-invalid @enderror">
                                        <option value="">Pilih Waktu Makan</option>
                                @foreach($waktuMakans as $waktu)
                                            <option value="{{ $waktu->id }}" {{ old('waktu_makan_id', $relasi->waktu_makan_id) == $waktu->id ? 'selected' : '' }}>
                                        {{ $waktu->nama }}
                                    </option>
                                @endforeach
                            </select>
                            @error('waktu_makan_id')
                                <div class="invalid-feedback">{{ $message }}</div>
                            @enderror
                    </div>
                </div>

                            <div class="col-md-4">
                                <div class="admin-form-group">
                                    <label class="admin-form-label">
                                        <i class="fas fa-toggle-on me-2"></i>Status
                                    </label>
                                    <select name="status" class="admin-form-control @error('status') is-invalid @enderror">
                                        <option value="1" {{ old('status', $relasi->status) == '1' ? 'selected' : '' }}>Aktif</option>
                                        <option value="0" {{ old('status', $relasi->status) == '0' ? 'selected' : '' }}>Tidak Aktif</option>
                    </select>
                    @error('status')
                        <div class="invalid-feedback">{{ $message }}</div>
                    @enderror
                                </div>
                            </div>
                </div>

                        <div class="text-end mt-4">
                            <a href="{{ route('relasi.index') }}" class="admin-btn btn-secondary me-2">
                        <i class="fas fa-arrow-left me-2"></i>Kembali
                    </a>
                            <button type="submit" class="admin-btn btn-primary">
                        <i class="fas fa-save me-2"></i>Simpan Perubahan
                    </button>
                </div>
            </form>
                </div>
            </div>
        </div>
    </div>
</div>
@endsection

@push('scripts')
<script>
document.addEventListener('DOMContentLoaded', function() {
    // Initialize Select2
    $('.admin-form-control').select2({
        theme: 'bootstrap-5',
        width: '100%'
    });

    // Animation
    const animateElements = document.querySelectorAll('.animate-fade-in');
    const observer = new IntersectionObserver((entries) => {
        entries.forEach(entry => {
            if (entry.isIntersecting) {
                entry.target.style.opacity = 1;
                entry.target.style.transform = 'translateY(0)';
            }
        });
    });

    animateElements.forEach(element => {
        element.style.opacity = 0;
        element.style.transform = 'translateY(20px)';
        observer.observe(element);
    });
});
</script>
@endpush
