@push('styles')
<style>
    /* Common Variables */
    :root {
        --primary-gradient: linear-gradient(135deg, #0d6efd 0%, #0099ff 100%);
        --secondary-gradient: linear-gradient(135deg, #6c757d 0%, #868e96 100%);
        --success-gradient: linear-gradient(135deg, #198754 0%, #28a745 100%);
        --warning-gradient: linear-gradient(135deg, #ffc107 0%, #ffcd39 100%);
        --danger-gradient: linear-gradient(135deg, #dc3545 0%, #e35d6a 100%);
        --card-shadow: 0 2px 4px rgba(0,0,0,0.1);
        --card-shadow-hover: 0 4px 8px rgba(0,0,0,0.2);
        --transition-speed: 0.3s;
        --border-radius: 12px;
        --spacing-unit: 1rem;
    }

    /* Layout & Containers */
    .admin-container {
        padding: var(--spacing-unit) 0;
        background-color: #f8f9fa;
        min-height: calc(100vh - 60px);
    }

    .page-header {
        background: var(--primary-gradient);
        padding: calc(var(--spacing-unit) * 2);
        border-radius: var(--border-radius);
        margin-bottom: calc(var(--spacing-unit) * 2);
        color: white;
        box-shadow: var(--card-shadow);
    }

    .stats-container {
        background: white;
        border-radius: var(--border-radius);
        padding: var(--spacing-unit);
        margin-bottom: var(--spacing-unit);
        box-shadow: var(--card-shadow);
    }

    /* Cards */
    .admin-card {
        transition: all var(--transition-speed) ease;
        border: none;
        box-shadow: var(--card-shadow);
        border-radius: var(--border-radius);
        height: 100%;
        background: white;
        overflow: hidden;
    }

    .admin-card:hover {
        transform: translateY(-5px);
        box-shadow: var(--card-shadow-hover);
    }

    .admin-card .card-header {
        border-radius: var(--border-radius) var(--border-radius) 0 0 !important;
        padding: var(--spacing-unit);
        border: none;
        background: white;
    }

    .admin-card .card-body {
        padding: var(--spacing-unit);
        background: white;
    }

    .admin-card .card-footer {
        background: white;
        border-top: 1px solid rgba(0,0,0,0.1);
        padding: var(--spacing-unit);
    }

    /* Feature Cards */
    .feature-card {
        position: relative;
        overflow: hidden;
        border-radius: var(--border-radius);
        background: white;
        transition: all var(--transition-speed) ease;
    }

    .feature-card::before {
        content: '';
        position: absolute;
        top: 0;
        left: 0;
        width: 100%;
        height: 4px;
        background: var(--primary-gradient);
    }

    .feature-card:hover {
        transform: translateY(-5px);
        box-shadow: var(--card-shadow-hover);
    }

    .feature-icon {
        width: 48px;
        height: 48px;
        border-radius: 12px;
        display: flex;
        align-items: center;
        justify-content: center;
        font-size: 24px;
        margin-bottom: 1rem;
        background: var(--primary-gradient);
        color: white;
    }

    /* Badges & Labels */
    .admin-badge {
        font-weight: 500;
        padding: 0.5em 0.8em;
        border-radius: 6px;
        transition: all 0.2s ease;
        background: var(--primary-gradient);
        color: white;
    }

    .admin-badge:hover {
        transform: scale(1.05);
    }

    /* Buttons */
    .admin-btn {
        padding: 0.5rem 1rem;
        border-radius: 6px;
        transition: all var(--transition-speed) ease;
        display: inline-flex;
        align-items: center;
        justify-content: center;
        gap: 0.5rem;
        font-weight: 500;
        color: white;
        border: none;
    }

    .admin-btn.btn-primary {
        background: var(--primary-gradient);
    }

    .admin-btn.btn-secondary {
        background: var(--secondary-gradient);
    }

    .admin-btn.btn-success {
        background: var(--success-gradient);
    }

    .admin-btn.btn-warning {
        background: var(--warning-gradient);
    }

    .admin-btn.btn-danger {
        background: var(--danger-gradient);
    }

    .admin-btn:hover {
        transform: translateY(-2px);
        color: white;
    }

    .admin-btn i {
        font-size: 0.9em;
    }

    /* Tables */
    .admin-table {
        width: 100%;
        margin-bottom: 1rem;
        background-color: white;
        border-collapse: collapse;
        border-radius: var(--border-radius);
        overflow: hidden;
    }

    .admin-table th,
    .admin-table td {
        padding: 1rem;
        vertical-align: middle;
        border-top: 1px solid #dee2e6;
    }

    .admin-table thead th {
        vertical-align: bottom;
        border-bottom: 2px solid #dee2e6;
        background-color: #f8f9fa;
        font-weight: 600;
        color: #495057;
    }

    .admin-table tbody tr:hover {
        background-color: rgba(13, 110, 253, 0.05);
    }

    /* Forms */
    .admin-form-group {
        margin-bottom: 1rem;
    }

    .admin-form-label {
        font-weight: 500;
        margin-bottom: 0.5rem;
        color: #495057;
    }

    .admin-form-control {
        display: block;
        width: 100%;
        padding: 0.5rem 0.75rem;
        font-size: 1rem;
        line-height: 1.5;
        border: 1px solid #ced4da;
        border-radius: var(--border-radius);
        transition: border-color var(--transition-speed) ease-in-out;
        background: white;
    }

    .admin-form-control:focus {
        border-color: #0d6efd;
        outline: 0;
        box-shadow: 0 0 0 0.2rem rgba(13, 110, 253, 0.25);
    }

    /* Alerts */
    .admin-alert {
        border-radius: var(--border-radius);
        margin-bottom: calc(var(--spacing-unit) * 2);
        padding: 1rem;
        border: none;
        background: white;
        box-shadow: var(--card-shadow);
    }

    /* Animations */
    .animate-fade-in {
        animation: fadeIn 0.5s ease-in;
    }

    @keyframes fadeIn {
        from { opacity: 0; transform: translateY(20px); }
        to { opacity: 1; transform: translateY(0); }
    }

    /* Responsive Utilities */
    @media (max-width: 768px) {
        .page-header {
            padding: var(--spacing-unit);
        }

        .stats-container {
            padding: calc(var(--spacing-unit) * 0.5);
        }

        .admin-card {
            margin-bottom: var(--spacing-unit);
        }

        .admin-table {
            display: block;
            width: 100%;
            overflow-x: auto;
            -webkit-overflow-scrolling: touch;
        }
    }
</style>
@endpush 