<!DOCTYPE html>
<html lang="en">

<head>
  <meta charset="utf-8" />
  <meta content="width=device-width, initial-scale=1.0" name="viewport" />

  <title>Login</title>

  <!-- Favicons -->
  <link href="{{ asset('logo/baru/dutdut.png') }}" rel="icon">

  <!-- Google Fonts -->
  <link href="https://fonts.gstatic.com" rel="preconnect" />
  <link href="https://fonts.googleapis.com/css2?family=Nunito:wght@400;600;700&display=swap" rel="stylesheet" />

  <!-- Vendor CSS -->
  <link href="{{ asset('assets/vendor/bootstrap/css/bootstrap.min.css') }}" rel="stylesheet" />
  <link href="{{ asset('assets/vendor/bootstrap-icons/bootstrap-icons.css') }}" rel="stylesheet" />
  <link href="{{ asset('assets/css/style.css') }}" rel="stylesheet" />

  <style>
    :root {
      --primary-color: #2196f3;
      --primary-light: rgba(33, 150, 243, 0.1);
      --text-color: #333;
      --border-radius: 10px;
      --box-shadow: 0 0 30px rgba(0, 0, 0, 0.08);
    }

    body {
      font-family: 'Nunito', sans-serif;
      background: linear-gradient(135deg, #e3f2fd, #bbdefb);
      min-height: 100vh;
    }

    .auth-container {
      min-height: 100vh;
      display: flex;
      align-items: center;
      justify-content: center;
      padding: 1.5rem;
    }

    .auth-card {
      width: 100%;
      max-width: 420px;
      border-radius: var(--border-radius);
      box-shadow: var(--box-shadow);
      background-color: #ffffff;
      transition: transform 0.3s ease;
    }

    .auth-card:hover {
      transform: translateY(-5px);
    }

    .auth-header {
      text-align: center;
      padding: 2rem 2rem 1rem;
    }

    .auth-title {
      color: var(--primary-color);
      font-size: 1.75rem;
      font-weight: 700;
      margin-bottom: 0.5rem;
    }

    .auth-subtitle {
      color: #6c757d;
      font-size: 0.95rem;
      margin-bottom: 1.5rem;
    }

    .auth-form {
      padding: 0 2rem 2rem;
    }

    .form-control {
      border: 1px solid #dee2e6;
      border-radius: 8px;
      padding: 0.75rem 1rem;
      font-size: 0.95rem;
      transition: all 0.3s ease;
    }

    .form-control:focus {
      border-color: var(--primary-color);
      box-shadow: 0 0 0 0.2rem var(--primary-light);
    }

    .form-label {
      color: var(--text-color);
      font-weight: 600;
      font-size: 0.9rem;
      margin-bottom: 0.5rem;
    }

    .btn-primary {
      background-color: var(--primary-color);
      border: none;
      border-radius: 8px;
      padding: 0.75rem 1.5rem;
      font-weight: 600;
      transition: all 0.3s ease;
    }

    .btn-primary:hover {
      background-color: #1976d2;
      transform: translateY(-2px);
      box-shadow: 0 4px 12px rgba(33, 150, 243, 0.3);
    }

    .auth-footer {
      text-align: center;
      padding-top: 1rem;
      font-size: 0.9rem;
    }

    .auth-footer a {
      color: var(--primary-color);
      text-decoration: none;
      font-weight: 600;
      transition: color 0.3s ease;
    }

    .auth-footer a:hover {
      color: #1976d2;
    }

    .alert {
      border-radius: 8px;
      margin-bottom: 1.5rem;
    }

    @media (max-width: 576px) {
      .auth-card {
        margin: 1rem;
      }

      .auth-header {
        padding: 1.5rem 1.5rem 1rem;
      }

      .auth-title {
        font-size: 1.5rem;
      }

      .auth-form {
        padding: 0 1.5rem 1.5rem;
      }

      .form-control {
        padding: 0.625rem 0.875rem;
        font-size: 0.9rem;
      }
    }
  </style>
</head>

<body>
  <main>
    <div class="auth-container">
      <div class="auth-card">
        <div class="auth-header">
          <h5 class="auth-title">Welcome Back!</h5>
          <p class="auth-subtitle">Please login to your account</p>
        </div>

        @if(session('error'))
        <div class="auth-form">
          <div class="alert alert-danger" role="alert">
            {{ session('error') }}
          </div>
        </div>
        @endif

        <form method="POST" action="{{ route('login.post') }}" class="auth-form needs-validation" novalidate>
          @csrf

          <div class="mb-3">
            <label for="yourEmail" class="form-label">Email Address</label>
            <input type="email" name="email" class="form-control" id="yourEmail" required>
            <div class="invalid-feedback">Please enter a valid email address.</div>
          </div>

          <div class="mb-4">
            <label for="yourPassword" class="form-label">Password</label>
            <div class="input-group">
              <input type="password" name="password" class="form-control" id="yourPassword" required>
              <button class="btn btn-outline-secondary" type="button" id="togglePassword">
                <i class="bi bi-eye-slash" id="toggleIcon"></i>
              </button>
              <div class="invalid-feedback">Please enter your password.</div>
            </div>
          </div>

          <div class="d-grid mb-4">
            <button class="btn btn-primary" type="submit">
              Sign In
            </button>
          </div>

          <div class="auth-footer">
            <p class="mb-0">Don't have an account? <a href="{{ route('register') }}">Create one</a></p>
          </div>
        </form>

      </div>
    </div>
  </main>

  <script src="{{ asset('assets/vendor/bootstrap/js/bootstrap.bundle.min.js') }}"></script>
  <script>
    (() => {
      'use strict'
      const forms = document.querySelectorAll('.needs-validation')
      Array.from(forms).forEach(form => {
        form.addEventListener('submit', event => {
          if (!form.checkValidity()) {
            event.preventDefault()
            event.stopPropagation()
          }
          form.classList.add('was-validated')
        }, false)
      })

      // Password visibility toggle
      const togglePassword = document.querySelector('#togglePassword');
      const password = document.querySelector('#yourPassword');
      const toggleIcon = document.querySelector('#toggleIcon');

      togglePassword.addEventListener('click', function () {
        const type = password.getAttribute('type') === 'password' ? 'text' : 'password';
        password.setAttribute('type', type);
        toggleIcon.classList.toggle('bi-eye');
        toggleIcon.classList.toggle('bi-eye-slash');
      });
    })()
  </script>
</body>

</html>
